openapi

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Dart package is automatically generated by the OpenAPI Generator project:

  • API version: 0.1.0
  • Build package: org.openapitools.codegen.languages.DartClientCodegen

Requirements

Dart 2.12 or later

Installation & Usage

Github

If this Dart package is published to Github, add the following dependency to your pubspec.yaml

dependencies:
  openapi:
    git: https://github.com/GIT_USER_ID/GIT_REPO_ID.git

Local

To use the package in your local drive, add the following dependency to your pubspec.yaml

dependencies:
  openapi:
    path: /path/to/openapi

Tests

TODO

Getting Started

Please follow the installation procedure and then run the following:

import 'package:private_gpt_api/api.dart';


final api_instance = ContextChunksApi();
final chunksBody = ChunksBody(); // ChunksBody | 

try {
    final result = api_instance.chunksRetrievalV1ChunksPost(chunksBody);
    print(result);
} catch (e) {
    print('Exception when calling ContextChunksApi->chunksRetrievalV1ChunksPost: $e\n');
}

Documentation for API Endpoints

All URIs are relative to http://localhost

Class Method HTTP request Description
ContextChunksApi chunksRetrievalV1ChunksPost POST /v1/chunks Chunks Retrieval
ContextualCompletionsApi chatCompletionV1ChatCompletionsPost POST /v1/chat/completions Chat Completion
ContextualCompletionsApi promptCompletionV1CompletionsPost POST /v1/completions Completion
EmbeddingsApi embeddingsGenerationV1EmbeddingsPost POST /v1/embeddings Embeddings Generation
HealthApi healthHealthGet GET /health Health
IngestionApi deleteIngestedV1IngestDocIdDelete DELETE /v1/ingest/{doc_id} Delete Ingested
IngestionApi ingestFileV1IngestFilePost POST /v1/ingest/file Ingest File
IngestionApi ingestTextV1IngestTextPost POST /v1/ingest/text Ingest Text
IngestionApi ingestV1IngestPost POST /v1/ingest Ingest
IngestionApi listIngestedV1IngestListGet GET /v1/ingest/list List Ingested

Documentation For Models

Documentation For Authorization

Endpoints do not require authorization.

Author

Libraries

api