api library
Classes
- ApiClient
- ApiKeyAuth
- Authentication
- ChatBody
- ChatBodyContextFilter
- Chunk
- ChunksBody
- ChunksResponse
- CompletionsBody
- Content
- ContextChunksApi
- ContextFilter
- ContextualCompletionsApi
- DeserializationMessage
- Primarily intended for use in an isolate.
- DocMetadata
- DocsIds
- Embedding
- EmbeddingsApi
- EmbeddingsBody
- EmbeddingsResponse
- FinishReason
- HealthApi
- HealthResponse
- HttpBasicAuth
- HttpBearerAuth
- HTTPValidationError
- IngestedDoc
- IngestionApi
- IngestResponse
- IngestTextBody
- Input
- NextTexts
- OAuth
- OpenAIChoice
- OpenAIChoiceDelta
- OpenAIChoiceMessage
- OpenAIChoiceMessageRoleEnum
- OpenAIChoiceMessageRoleEnumTypeTransformer
- Transformation class that can encode an instance of OpenAIChoiceMessageRoleEnum to Object, and decode dynamic data back to OpenAIChoiceMessageRoleEnum.
- OpenAICompletion
- OpenAICompletionObjectEnum
- OpenAICompletionObjectEnumTypeTransformer
- Transformation class that can encode an instance of OpenAICompletionObjectEnum to String, and decode dynamic data back to OpenAICompletionObjectEnum.
- OpenAIDelta
- OpenAIMessage
- OpenAIMessageRoleEnum
- OpenAIMessageRoleEnumTypeTransformer
- Transformation class that can encode an instance of OpenAIMessageRoleEnum to String, and decode dynamic data back to OpenAIMessageRoleEnum.
- PreviousTexts
- QueryParam
- Sources
- SystemPrompt
- ValidationError
- ValidationErrorLocInner
Properties
- defaultApiClient ↔ ApiClient
-
An ApiClient instance that uses the default values obtained from
the OpenAPI specification file.
getter/setter pair
Functions
-
decodeAsync(
DeserializationMessage message) → Future - Primarily intended for use in an isolate.
-
deserializeAsync(
DeserializationMessage message) → Future - Primarily intended for use in an isolate.
-
mapCastOfType<
K, V> (dynamic map, String key) → Map< K, V> ? -
Returns a valid Map<K, V> found at the specified Map
key, null otherwise. -
mapDateTime(
dynamic map, String key, [String? pattern]) → DateTime? -
Returns a valid DateTime found at the specified Map
key, null otherwise. -
mapValueOfType<
T> (dynamic map, String key) → T? -
Returns a valid
Tvalue found at the specified Mapkey, null otherwise. -
parameterToString(
dynamic value) → String - Format the given parameter object into a String.
-
serializeAsync(
Object? value) → Future< String> - Primarily intended for use in an isolate.
Typedefs
- HttpBearerAuthProvider = String Function()