Chunk class
Constructors
- Chunk({required Object? object, required num score, required IngestedDoc document, required String text, PreviousTexts? previousTexts, NextTexts? nextTexts})
- Returns a new Chunk instance.
Properties
- document ↔ IngestedDoc
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextTexts ↔ NextTexts?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
- object ↔ Object?
-
getter/setter pair
- previousTexts ↔ PreviousTexts?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score ↔ num
-
getter/setter pair
- text ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → Chunk? -
Returns a new Chunk instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< Chunk> -
mapFromJson(
dynamic json) → Map< String, Chunk> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< Chunk> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.