CompletionsBody class

Constructors

CompletionsBody({required String prompt, SystemPrompt? systemPrompt, bool useContext = false, ChatBodyContextFilter? contextFilter, bool includeSources = true, bool stream = false})
Returns a new CompletionsBody instance.

Properties

contextFilter ChatBodyContextFilter?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
includeSources bool
getter/setter pair
prompt String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream bool
getter/setter pair
systemPrompt SystemPrompt?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
useContext bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CompletionsBody?
Returns a new CompletionsBody instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CompletionsBody>
mapFromJson(dynamic json) Map<String, CompletionsBody>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CompletionsBody>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.