ContextChunksApi class

Constructors

ContextChunksApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

chunksRetrievalV1ChunksPost(ChunksBody chunksBody) Future<ChunksResponse?>
Chunks Retrieval
chunksRetrievalV1ChunksPostWithHttpInfo(ChunksBody chunksBody) Future<Response>
Chunks Retrieval
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited