embeddingsGenerationV1EmbeddingsPost method

Future<EmbeddingsResponse?> embeddingsGenerationV1EmbeddingsPost(
  1. EmbeddingsBody embeddingsBody
)

Embeddings Generation

Get a vector representation of a given input. That vector representation can be easily consumed by machine learning models and algorithms.

Parameters:

Implementation

Future<EmbeddingsResponse?> embeddingsGenerationV1EmbeddingsPost(EmbeddingsBody embeddingsBody,) async {
  final response = await embeddingsGenerationV1EmbeddingsPostWithHttpInfo(embeddingsBody,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'EmbeddingsResponse',) as EmbeddingsResponse;

  }
  return null;
}