IngestResponse class
Constructors
-
IngestResponse({required Object? object, required Object? model, List<
IngestedDoc> data = const []}) - Returns a new IngestResponse instance.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → IngestResponse? -
Returns a new IngestResponse instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< IngestResponse> -
mapFromJson(
dynamic json) → Map< String, IngestResponse> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< IngestResponse> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.