IngestTextBody class

Constructors

IngestTextBody({required String fileName, required String text})
Returns a new IngestTextBody instance.

Properties

fileName String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) IngestTextBody?
Returns a new IngestTextBody instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<IngestTextBody>
mapFromJson(dynamic json) Map<String, IngestTextBody>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<IngestTextBody>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.