IngestedDoc class

Constructors

IngestedDoc({required Object? object, required String docId, required DocMetadata docMetadata})
Returns a new IngestedDoc instance.

Properties

docId String
getter/setter pair
docMetadata DocMetadata
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
object Object?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) IngestedDoc?
Returns a new IngestedDoc instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<IngestedDoc>
mapFromJson(dynamic json) Map<String, IngestedDoc>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<IngestedDoc>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.