IngestionApi class

Constructors

IngestionApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteIngestedV1IngestDocIdDelete(String docId) Future<Object?>
Delete Ingested
deleteIngestedV1IngestDocIdDeleteWithHttpInfo(String docId) Future<Response>
Delete Ingested
ingestFileV1IngestFilePost(MultipartFile file) Future<IngestResponse?>
Ingest File
ingestFileV1IngestFilePostWithHttpInfo(MultipartFile file) Future<Response>
Ingest File
ingestTextV1IngestTextPost(IngestTextBody ingestTextBody) Future<IngestResponse?>
Ingest Text
ingestTextV1IngestTextPostWithHttpInfo(IngestTextBody ingestTextBody) Future<Response>
Ingest Text
ingestV1IngestPost(MultipartFile file) Future<IngestResponse?>
Ingest
ingestV1IngestPostWithHttpInfo(MultipartFile file) Future<Response>
Ingest
listIngestedV1IngestListGet() Future<IngestResponse?>
List Ingested
listIngestedV1IngestListGetWithHttpInfo() Future<Response>
List Ingested
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited