listIngestedV1IngestListGet method

Future<IngestResponse?> listIngestedV1IngestListGet()

List Ingested

Lists already ingested Documents including their Document ID and metadata. Those IDs can be used to filter the context used to create responses in /chat/completions, /completions, and /chunks APIs.

Implementation

Future<IngestResponse?> listIngestedV1IngestListGet() async {
  final response = await listIngestedV1IngestListGetWithHttpInfo();
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'IngestResponse',) as IngestResponse;

  }
  return null;
}