Input class

Constructors

Input()
Returns a new Input instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Input?
Returns a new Input instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Input>
mapFromJson(dynamic json) Map<String, Input>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Input>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.