deleteIngestedV1IngestDocIdDelete method
Delete Ingested
Delete the specified ingested Document. The doc_id can be obtained from the GET /ingest/list endpoint. The document will be effectively deleted from your storage context.
Parameters:
- String docId (required):
Implementation
Future<Object?> deleteIngestedV1IngestDocIdDelete(String docId,) async {
final response = await deleteIngestedV1IngestDocIdDeleteWithHttpInfo(docId,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'Object',) as Object;
}
return null;
}